Bare

Struct Bare 

pub struct Bare<Pk>
where Pk: MiniscriptKey,
{ /* private fields */ }
Create a Bare Descriptor. That is descriptor that is not wrapped in sh or wsh. This covers the Pk descriptor

Implementations

Source

impl<Pk> Bare<Pk>
where Pk: MiniscriptKey,

pub fn new(ms: Miniscript<Pk, BareCtx>) -> Result<Bare<Pk>, Error>

Create a new raw descriptor

pub fn into_inner(self) -> Miniscript<Pk, BareCtx>

get the inner

pub fn as_inner(&self) -> &Miniscript<Pk, BareCtx>

get the inner

pub fn sanity_check(&self) -> Result<(), Error>

Checks whether the descriptor is safe.

pub fn max_weight_to_satisfy(&self) -> Result<Weight, Error>

Computes an upper bound on the difference between a non-satisfied TxIn’s segwit_weight and a satisfied TxIn’s segwit_weight

Since this method uses segwit_weight instead of legacy_weight, if you want to include only legacy inputs in your transaction, you should remove 1WU from each input’s max_weight_to_satisfy for a more accurate estimate.

Assumes all ECDSA signatures are 73 bytes, including push opcode and sighash suffix.

Errors

When the descriptor is impossible to safisfy (ex: sh(OP_FALSE)).

pub fn max_satisfaction_weight(&self) -> Result<usize, Error>

👎Deprecated since 10.0.0:

Use max_weight_to_satisfy instead. The method to count bytes was redesigned and the results will differ from max_weight_to_satisfy. For more details check rust-bitcoin/rust-miniscript#476.

Computes an upper bound on the weight of a satisfying witness to the transaction.

Assumes all ec-signatures are 73 bytes, including push opcode and sighash suffix. Includes the weight of the VarInts encoding the scriptSig and witness stack length.

Errors

When the descriptor is impossible to safisfy (ex: sh(OP_FALSE)).

Source

impl<Pk> Bare<Pk>

pub fn script_pubkey(&self) -> ScriptBuf

Obtains the corresponding script pubkey for this descriptor.

pub fn inner_script(&self) -> ScriptBuf

Obtains the underlying miniscript for this descriptor.

pub fn ecdsa_sighash_script_code(&self) -> ScriptBuf

Obtains the pre bip-340 signature script code for this descriptor.

pub fn get_satisfaction<S>( &self, satisfier: S, ) -> Result<(Vec<Vec<u8>>, ScriptBuf), Error>
where S: Satisfier<Pk>,

Returns satisfying non-malleable witness and scriptSig with minimum weight to spend an output controlled by the given descriptor if it is possible to construct one using the satisfier.

pub fn get_satisfaction_mall<S>( &self, satisfier: S, ) -> Result<(Vec<Vec<u8>>, ScriptBuf), Error>
where S: Satisfier<Pk>,

Returns satisfying, possibly malleable, witness and scriptSig with minimum weight to spend an output controlled by the given descriptor if it is possible to construct one using the satisfier.

Source

impl Bare<DefiniteDescriptorKey>

pub fn plan_satisfaction<P>( &self, provider: &P, ) -> Satisfaction<Placeholder<DefiniteDescriptorKey>>

Returns a plan if the provided assets are sufficient to produce a non-malleable satisfaction

pub fn plan_satisfaction_mall<P>( &self, provider: &P, ) -> Satisfaction<Placeholder<DefiniteDescriptorKey>>

Returns a plan if the provided assets are sufficient to produce a malleable satisfaction